@@ -3,11 +3,12 @@ Main interface for iot1click-devices service type definitions.
 
 Usage::
 
-    from mypy_boto3.iot1click_devices.type_defs import DeviceDescriptionTypeDef
+    ```python
+    from mypy_boto3_iot1click_devices.type_defs import DeviceDescriptionTypeDef
 
     data: DeviceDescriptionTypeDef = {...}
+    ```
 """
-import sys
 from typing import Any, Dict, List
 
 if sys.version_info >= (3, 8):
